
use 数据.dta, clear

*建立主观感受因子f1
factor pubsatisfy pubimpr pubfair happy, pcf
rotate
predict f1
estat kmo

*生成应纳税所得额（不含税）mtaxinc
gen mtaxinc=msalary-3500

*生成税率t
gen t=0 if mtaxinc<=0
replace t=0.03 if mtaxinc<=1455 & mtaxinc>0
replace t=0.1 if mtaxinc>1455 & mtaxinc<=4155
replace t=0.2 if mtaxinc>4155 & mtaxinc<=7755
replace t=0.25 if mtaxinc>7755 & mtaxinc<=27255
replace t=0.3 if mtaxinc>27255 & mtaxinc<=41255
replace t=0.35 if mtaxinc>41255 & mtaxinc<=57505 
replace t=0.45 if mtaxinc>57505 & mtaxinc<.

*建立速算扣除数q
gen q=0 if mtaxinc<=1455
replace q=105 if mtaxinc>1455 & mtaxinc<=4155 
replace q=555 if mtaxinc>4155 & mtaxinc<=7755
replace q=1005 if mtaxinc>7755 & mtaxinc<=27255
replace q=2755 if mtaxinc>27255 & mtaxinc<=41255
replace q=5505 if mtaxinc>41255 & mtaxinc<=57505
replace q=13505 if mtaxinc>57505 & mtaxinc<.

*计算税前月工薪收入mbsalary
gen mbsalary=(msalary-3500*t-q)/(1-t)+limit/3*0.6*per if msalary<y1 
replace mbsalary=(msalary-3500*t-q)/(1-per)/(1-t) if msalary<=y0 & msalary>=y1 
replace mbsalary=(msalary-3500*t-q)/(1-t)+limit*per if msalary>y0

*建立税前年工薪收入ybsalary
gen ybsalary=mbsalary*workti

*计算应纳税所得额（含税）mbtaxinc
gen mbtaxinc=mbsalary-3500-limit/3*0.6*per if msalary<y1
replace mbtaxinc=mbsalary-3500-mbsalary*per if msalary<=y0 & msalary>=y1
replace mbtaxinc=mbsalary-3500-limit*per if msalary>y0 
replace mbtaxinc=0 if mbtaxinc<0

*计算真实月税额rtax
gen rtax=mbtaxinc*t-q

*计算真实年税额
**首先计算工作时间不到一个月者的年税额
gen yrtax=rtax if workti<1 

**其次计算工作时间超过一个月者的年税额
*建立工作零头月的税后月收入hmsalary
gen hmsalary = msalary*(workti-int(workti))
*建立零头月的不含税应纳税所得额hmtaxinc：
gen hmtaxinc=hmsalary-3500
*生成零头月适用的税率ht
gen ht=0 if hmtaxinc<=0
replace ht=0.03 if hmtaxinc<=1455 & hmtaxin>0
replace ht=0.1 if hmtaxinc>1455 & hmtaxinc<=4155
replace ht=0.2 if hmtaxinc>4155 & hmtaxinc<=7755
replace ht=0.25 if hmtaxinc>7755 & hmtaxinc<=27255
replace ht=0.3 if hmtaxinc>27255 & hmtaxinc<=41255
replace ht=0.35 if hmtaxinc>41255 & hmtaxinc<=57505 
replace ht=0.45 if hmtaxinc>57505 & hmtaxinc<. 
*建立零头月速算扣除数变量hq
gen hq=0 if hmtaxinc<=1455
replace hq=105 if hmtaxinc>1455 & hmtaxinc<=4155
replace hq=555 if hmtaxinc>4155 & hmtaxinc<=7755
replace hq=1005 if hmtaxinc>7755 & hmtaxinc<=27255
replace hq=2755 if hmtaxinc>27255 & hmtaxinc<=41255
replace hq=5505 if hmtaxinc>41255 & hmtaxinc<=57505
replace hq=13505 if hmtaxinc>57505 & hmtaxinc<.
*计算零头月税前收入hmbsalary：
gen hmbsalary=(hmsalary-3500*ht-hq)/(1-ht)+limit/3*0.6*per if hmsalary<y1
replace hmbsalary=(hmsalary-3500*ht-hq)/(1-ht)+mbsalary*per if hmsalary<=y0 & hmsalary>=y1   
replace hmbsalary=(hmsalary-3500*ht-hq)/(1-ht)+limit*per if hmsalary>y0
*计算零头月应纳税所得额（含税）hmbtaxinc：
gen hmbtaxinc=hmbsalary-3500-limit/3*0.6*per if hmsalary<y1
replace hmbtaxinc=hmbsalary-3500-hmbsalary*per if hmsalary<=y0 & hmsalary>=y1
replace hmbtaxinc=hmbsalary-3500-limit*per if hmsalary>y0 
replace hmbtaxinc=0 if hmbtaxinc<0 
*计算零头月真实月税额：
gen hrtax=hmbtaxinc*ht-hq
*计算工作时间超过一个月者的年税额（整数月税额+零头月税额）
replace yrtax=rtax*int(workti)+hrtax if workti>=1

*建立年个税认知偏差变量taxbias
gen taxbias=tax-yrtax

*建立报告平均税率arate和测算平均税率arrrate
gen arate=tax/ybsalary
gen arrate=yrtax/ybsalary

*建立感知税率偏差变量ratebias15-30
gen ratebias15=(arate-arrate)-0.15*arrate if (arate-arrate)>0.15*arrate
replace ratebias15=(arate-arrate)+0.15*arrate if (arate-arrate)<-0.15*arrate
replace ratebias15=0 if abs(arate-arrate)<=0.15*arrate & arrate<.

gen ratebias20=(arate-arrate)-0.2*arrate if (arate-arrate)>0.2*arrate
replace ratebias20=(arate-arrate)+0.2*arrate if (arate-arrate)<-0.2*arrate
replace ratebias20=0 if abs(arate-arrate)<=0.2*arrate & arrate<.

gen ratebias25=(arate-arrate)-0.25*arrate if (arate-arrate)>0.25*arrate
replace ratebias25=(arate-arrate)+0.25*arrate if (arate-arrate)<-0.25*arrate
replace ratebias25=0 if abs(arate-arrate)<=0.25*arrate & arrate<.

gen ratebias30=(arate-arrate)-0.3*arrate if (arate-arrate)>0.3*arrate
replace ratebias30=(arate-arrate)+0.3*arrate if (arate-arrate)<-0.3*arrate
replace ratebias30=0 if abs(arate-arrate)<=0.3*arrate & arrate<.

*建立税负高估和税负低估虚拟变量hbias15-30和lbias15-30
gen hbias15=1 if ratebias15>0 & ratebias15<.
replace hbias15=0 if ratebias15<=0

gen lbias15=1 if ratebias15<0
replace lbias15=0 if ratebias15>=0 & ratebias15<.

gen hbias20=1 if ratebias20>0 & ratebias20<.
replace hbias20=0 if ratebias20<=0

gen lbias20=1 if ratebias20<0
replace lbias20=0 if ratebias20>=0 & ratebias20<.

gen hbias25=1 if ratebias25>0 & ratebias25<.
replace hbias25=0 if ratebias25<=0

gen lbias25=1 if ratebias25<0
replace lbias25=0 if ratebias25>=0 & ratebias25<.

gen hbias30=1 if ratebias30>0 & ratebias30<.
replace hbias30=0 if ratebias30<=0

gen lbias30=1 if ratebias30<0
replace lbias30=0 if ratebias30>=0 & ratebias30<.

*建立感知税负偏差倾向mbias15-30
gen mbias15=3 if ratebias15>0 & ratebias15<.
replace mbias15=2 if ratebias15==0
replace mbias15=1 if ratebias15<0

gen mbias20=3 if ratebias20>0 & ratebias20<.
replace mbias20=2 if ratebias20==0
replace mbias20=1 if ratebias20<0

gen mbias25=3 if ratebias25>0 & ratebias25<.
replace mbias25=2 if ratebias25==0
replace mbias25=1 if ratebias25<0

gen mbias30=3 if ratebias30>0 & ratebias30<.
replace mbias30=2 if ratebias30==0
replace mbias30=1 if ratebias30<0

*建立感知税负错误虚拟变量bbias25
gen bbias25=1 if mbias25==3 | mbias25==1
replace bbias25=0 if mbias25==2

*样本的基本特征
sum age
tab gender
tab marr
tab edu
sum ssn
sum per
sum mbsalary
sum t
tab t

*ratebias25核密度图
kdensity ratebias25, norm width(0.003) gau xlabel(-0.2(0.1)0.4) xtitle("ratebias") ylabel(, nogrid angle(horizontal)) graphregion(fcolor(white)) legend(cols(2) position(12) region(lwidth(0))) title("") normopts(lpattern(dash))


*实证检验

local varia1 lnsalary age gender edu marr per ecoinf f1 supv lnaincome wcapital i.status i.career
local varia2 lnsalary2015 age gender edu marr per ecoinf f1 supv lnaincome wcapital i.status i.career
local varia3 age gender marr per ecoinf f1 supv lnaincome wcapital i.status i.career
local varia4 lnsalary age edu marr per ecoinf f1 supv lnaincome wcapital i.status i.career

*描述性统计：
tab mbias25
sum bbias25 lnsalary age gender edu marr per ecoinf f1 happy pubsatisfy pubimpr pubfair supv

*基准回归：
mlogit mbias25 `varia1', base(2) nolog


*稳健性检验
*排除内生性（以lnsalary2015替代lnsalary）
mlogit mbias25 `varia2', base(2) nolog

*以bbias25替代mbias25
logit bbias25 `varia1', nolog

*建立样本选择偏差模型
heckprobit bbias25 `varia1', select(`varia1' i.wtype) nolog

*将税负感知正确的标准改为|perbias|≤20%：
mlogit mbias20 `varia1', nolog

*将税负感知正确的标准改为|perbias|≤30%：
mlogit mbias30 `varia1', nolog

*调节效应检验：
mlogit mbias25 c.lnsalary##c.edu `varia3', base(2) nolog

*异质性分析
*低收入组
mlogit mbias25 `varia1' if salarysplit==0, base(2) nolog

*高收入组
mlogit mbias25 `varia1' if salarysplit==1, base(2) nolog

*女性
mlogit mbias25 `varia4' if gender ==1, base(2) nolog

*男性
mlogit mbias25 `varia4' if gender ==0, base(2) nolog


